$STITLE 2report2.inc: creating reports
* IFPRI Extended standard modeling system, Version 2.00

*Load reporting sets and mappings
$call "gdxxrw i=%simdata% o=z3rep.gdx index=repindex2!a6"
$gdxin z3rep.gdx

SET
 RA      activity reporting accounts
 RAG     aggregate activity reporting accounts
*R
 RC      commodity reporting accounts
*R
 RCG     aggregate commodity reporting accounts
 DA      reporting demand accounts
         / dGDP, dPRVCON, dINVEST, dGOVCON, dEXPORT, dIMPORT/
 MCA(C,A)
 MCRA(C,RA)
 MCRC(C,RC)
;

ALIAS (RA,RAP), (DA,DAP);

PARAMETER
*Mappings
 MARA(A,RA)          mapping between activities and aggregates
*Supply-side reporting parameters
 sVALUE(RA,SIM)      GDP at factor cost
 sSHARE(RA,SIM)      share of GDP at factor cost
 sGROWTH(RA,SIM)     change in GDP at factor cost
 sCONTR(RA,SIM)      contribution to change in GDP
*Demand-side reporting parameters
 dVALUE(DA,SIM)      GDP at market prices
 dSHARE(DA,SIM)      share of GDP at market prices
 dGROWTH(DA,SIM)     change in GDP at market prices
 dCONTR(DA,SIM)      contribution to change in GDP
*Import and export growth rates by aggregate commodity
 QETAB(RA,SIM)       real export value
 QMTAB(RA,SIM)       real import value
 YITAB(AC,SIM)       institutional incomes
*R QHTAB2(RA,SIM)      real household spending
 QHTAB2(RC,SIM)      real household spending
*Prices
 PXTAB(RA,SIM)       output supply prices
 PQTAB(RA,SIM)       final composite demand prices
 PETAB(RA,SIM)       export prices
 PMTAB(RA,SIM)       import prices
;

*Load sets and mappings from excel file 3report.xls
*$load RA RAG MARA MCA
$load RA RAG RC RCG MARA MCA MCRC
*Ensure that there are no mapping entries for total GDP at factor cost
 MARA(A,'sGDP') = 0;
*Mapping between reporting activities and commodities
 MCRA(C,RA) = SUM(A$MCA(C,A), MARA(A,RA));

*----------------------------------------------------------------------------------------------------------------------
*Growth decompositions (Supply-side and demand-side) --------------------------
*----------------------------------------------------------------------------------------------------------------------

*Calculate supply-side decomposition (GDP at factor cost) ------------
*Values and shares
 sVALUE(RA,SIMCUR)     = SUM(A$MARA(A,RA), PVA0(A)*(1-tva0(A))*QVAX(A,SIMCUR));
 sSHARE(RA,SIMCUR)     = sVALUE(RA,SIMCUR) / SUM(RAP$(NOT RAG(RAP)), sVALUE(RAP,SIMCUR))*100;
 sVALUE('sGDP',SIMCUR) = SUM(RA$(NOT RAG(RA)), sVALUE(RA,SIMCUR));
 sSHARE('sGDP',SIMCUR) = SUM(RA$(NOT RAG(RA)), sSHARE(RA,SIMCUR));
*Growth rates
 sGROWTH(RA,SIMCUR)$sVALUE(RA,'BASE') = (sVALUE(RA,SIMCUR)/sVALUE(RA,'BASE')-1)*100;
 SGROWTH(RA,'BASE') = sSHARE(RA,'BASE');
*Contribution to growth
 sCONTR(RA,SIMCUR) = sSHARE(RA,'BASE')/100*sGROWTH(RA,SIMCUR);
 sCONTR(RA,'BASE') = sSHARE(RA,'BASE');

*Calculate supply-side decomposition of growth (GDP at factor cost) ------------
*Values and shares
 dVALUE('dPRVCON',SIMCUR) = GDPTAB1('REAL','PRVCON' ,SIMCUR);
 dVALUE('dINVEST',SIMCUR) = GDPTAB1('REAL','FIXINV' ,SIMCUR) + GDPTAB1('REAL','DSTOCK',SIMCUR);
 dVALUE('dGOVCON',SIMCUR) = GDPTAB1('REAL','GOVCON' ,SIMCUR);
 dVALUE('dEXPORT',SIMCUR) = GDPTAB1('REAL','EXPORTS',SIMCUR);
 dVALUE('dIMPORT',SIMCUR) = GDPTAB1('REAL','IMPORTS',SIMCUR);
 dSHARE(DA,SIMCUR)        = dVALUE(DA,SIMCUR) / SUM(DAP, dVALUE(DAP,SIMCUR))*100;
 dVALUE('dGDP',SIMCUR)    = SUM(DA, dVALUE(DA,SIMCUR));
 dSHARE('dGDP',SIMCUR)    = SUM(DA, dSHARE(DA,SIMCUR));
*Annual growth rates
 dGROWTH(DA,SIMCUR)$dVALUE(DA,'BASE') = (dVALUE(DA,SIMCUR)/dVALUE(DA,'BASE')-1)*100;
 dGROWTH(DA,SIMCUR) = dSHARE(DA,SIMCUR);
*Annual contribution to growth
 dCONTR(DA,SIMCUR) = dSHARE(DA,'BASE')/100*dGROWTH(DA,SIMCUR);

*----------------------------------------------------------------------------------------------------------------------
*Export and import tables -----------------------------------------------------
*----------------------------------------------------------------------------------------------------------------------

*Changes
 QETAB(RA,SIMCUR)$SUM(C$MCRA(C,RA), PE0(C)*QE0(C)) = (SUM(C$MCRA(C,RA), PE0(C)*QEX(C,SIMCUR))/SUM(C$MCRA(C,RA), PE0(C)*QE0(C))-1)*100;
 QMTAB(RA,SIMCUR)$SUM(C$MCRA(C,RA), PM0(C)*QM0(C)) = (SUM(C$MCRA(C,RA), PM0(C)*QMX(C,SIMCUR))/SUM(C$MCRA(C,RA), PM0(C)*QM0(C))-1)*100;
*Initial shares
 QETAB(RA,'BASE')$SUM(C, PE0(C)*QE0(C)) = SUM(C$MCRA(C,RA), PE0(C)*QE0(C))/SUM(C, PE0(C)*QE0(C))*100;
 QMTAB(RA,'BASE')$SUM(C, PM0(C)*QM0(C)) = SUM(C$MCRA(C,RA), PM0(C)*QM0(C))/SUM(C, PM0(C)*QM0(C))*100;

*RJD Adjusted to do commodity prices directly
PARAMETER
 QETAB2(RC,SIM)       real export value
 QMTAB2(RC,SIM)       real import value
*DvS Mar2012
 QDTAB2(RC,SIM)       real domestic sales value
 QQTAB2(RC,SIM)       real composite supply value
 ;
*Changes
 QETAB2(RC,SIMCUR)$SUM(C$MCRC(C,RC), QE0(C)) = SUM(C$MCRC(C,RC), QEX(C,SIMCUR) * PEX(C,SIMCUR)*QEX(C,SIMCUR) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PEX(CP,SIMCUR)*QEX(CP,SIMCUR)));
 QMTAB2(RC,SIMCUR)$SUM(C$MCRC(C,RC), QM0(C)) = SUM(C$MCRC(C,RC), QMX(C,SIMCUR) * PMX(C,SIMCUR)*QMX(C,SIMCUR) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PMX(CP,SIMCUR)*QMX(CP,SIMCUR)));
*DvS Mar2012
 QDTAB2(RC,SIMCUR)$SUM(C$MCRC(C,RC), QD0(C)) = SUM(C$MCRC(C,RC), QDX(C,SIMCUR) * PDDX(C,SIMCUR)*QDX(C,SIMCUR) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PDDX(CP,SIMCUR)*QDX(CP,SIMCUR)));
 QQTAB2(RC,SIMCUR)$SUM(C$MCRC(C,RC), QQ0(C)) = SUM(C$MCRC(C,RC), QQX(C,SIMCUR) * PQX(C,SIMCUR)*QQX(C,SIMCUR) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PQX(CP,SIMCUR)*QQX(CP,SIMCUR)));

*Initial shares
* PETAB2(RC,SIMCUR)$PETAB2(RC,'BASE') = (PETAB2(RC,SIMCUR)/PETAB2(RC,'BASE')-1)*100;
 QETAB2(RC,SIMCUR)$QETAB2(RC,'BASE') = (QETAB2(RC,SIMCUR)/QETAB2(RC,'BASE')-1)*100;
 QMTAB2(RC,SIMCUR)$QMTAB2(RC,'BASE') = (QMTAB2(RC,SIMCUR)/QMTAB2(RC,'BASE')-1)*100;
*DvS Mar2012
 QDTAB2(RC,SIMCUR)$QDTAB2(RC,'BASE') = (QDTAB2(RC,SIMCUR)/QDTAB2(RC,'BASE')-1)*100;
 QQTAB2(RC,SIMCUR)$QQTAB2(RC,'BASE') = (QQTAB2(RC,SIMCUR)/QQTAB2(RC,'BASE')-1)*100;

 QETAB2(RC,'BASE')$SUM(C$MCRC(C,RC), QE0(C)) = SUM(C$MCRC(C,RC), PE0(C)*QE0(C));
 QMTAB2(RC,'BASE')$SUM(C$MCRC(C,RC), QM0(C)) = SUM(C$MCRC(C,RC), PM0(C)*QM0(C));
*DvS Mar2012
 QDTAB2(RC,'BASE')$SUM(C$MCRC(C,RC), QD0(C)) = SUM(C$MCRC(C,RC), PDD0(C)*QD0(C));
 QQTAB2(RC,'BASE')$SUM(C$MCRC(C,RC), QQ0(C)) = SUM(C$MCRC(C,RC), PQ0(C)*QQ0(C));

*----------------------------------------------------------------------------------------------------------------------
*Prices tables ----------------------------------------------------------------
*----------------------------------------------------------------------------------------------------------------------

 PXTAB(RA,SIMCUR)$SUM(C$MCRA(C,RA), QX0(C)) = SUM(C$MCRA(C,RA), PXX(C,SIMCUR) * PXX(C,SIMCUR)*QXX(C,SIMCUR) / SUM(CP$(MCRA(C,RA) AND MCRA(CP,RA)), PXX(CP,SIMCUR)*QXX(CP,SIMCUR)));
 PQTAB(RA,SIMCUR)$SUM(C$MCRA(C,RA), QQ0(C)) = SUM(C$MCRA(C,RA), PQX(C,SIMCUR) * PQX(C,SIMCUR)*QQX(C,SIMCUR) / SUM(CP$(MCRA(C,RA) AND MCRA(CP,RA)), PQX(CP,SIMCUR)*QQX(CP,SIMCUR)));
 PETAB(RA,SIMCUR)$SUM(C$MCRA(C,RA), QE0(C)) = SUM(C$MCRA(C,RA), PEX(C,SIMCUR) * PEX(C,SIMCUR)*QEX(C,SIMCUR) / SUM(CP$(MCRA(C,RA) AND MCRA(CP,RA)), PEX(CP,SIMCUR)*QEX(CP,SIMCUR)));
 PMTAB(RA,SIMCUR)$SUM(C$MCRA(C,RA), QM0(C)) = SUM(C$MCRA(C,RA), PMX(C,SIMCUR) * PMX(C,SIMCUR)*QMX(C,SIMCUR) / SUM(CP$(MCRA(C,RA) AND MCRA(CP,RA)), PMX(CP,SIMCUR)*QMX(CP,SIMCUR)));

 PXTAB(RA,SIMCUR)$PXTAB(RA,'BASE') = (PXTAB(RA,SIMCUR)/PXTAB(RA,'BASE')-1)*100;
 PQTAB(RA,SIMCUR)$PQTAB(RA,'BASE') = (PQTAB(RA,SIMCUR)/PQTAB(RA,'BASE')-1)*100;
 PETAB(RA,SIMCUR)$PETAB(RA,'BASE') = (PETAB(RA,SIMCUR)/PETAB(RA,'BASE')-1)*100;
 PMTAB(RA,SIMCUR)$PMTAB(RA,'BASE') = (PMTAB(RA,SIMCUR)/PMTAB(RA,'BASE')-1)*100;

 PXTAB(RA,'BASE')$SUM(C$MCRA(C,RA), QX0(C)) = SUM(C$MCRA(C,RA), PX0(C) * PX0(C)*QX0(C) / SUM(CP$(MCRA(C,RA) AND MCRA(CP,RA)), PX0(CP)*QX0(CP)));
 PQTAB(RA,'BASE')$SUM(C$MCRA(C,RA), QQ0(C)) = SUM(C$MCRA(C,RA), PQ0(C) * PQ0(C)*QQ0(C) / SUM(CP$(MCRA(C,RA) AND MCRA(CP,RA)), PQ0(CP)*QQ0(CP)));
 PETAB(RA,'BASE')$SUM(C$MCRA(C,RA), QE0(C)) = SUM(C$MCRA(C,RA), PE0(C) * PE0(C)*QE0(C) / SUM(CP$(MCRA(C,RA) AND MCRA(CP,RA)), PE0(CP)*QE0(CP)));
 PMTAB(RA,'BASE')$SUM(C$MCRA(C,RA), QM0(C)) = SUM(C$MCRA(C,RA), PM0(C) * PM0(C)*QM0(C) / SUM(CP$(MCRA(C,RA) AND MCRA(CP,RA)), PM0(CP)*QM0(CP)));

*RJD Adjusted to do commodity prices directly
PARAMETER
 PXTAB2(RC,SIM)       output supply prices
 PQTAB2(RC,SIM)       final composite demand prices
 PETAB2(RC,SIM)       export prices
 PMTAB2(RC,SIM)       import prices
 ;

 PXTAB2(RC,SIMCUR)$SUM(C$MCRC(C,RC), QX0(C)) = SUM(C$MCRC(C,RC), PXX(C,SIMCUR) * PXX(C,SIMCUR)*QXX(C,SIMCUR) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PXX(CP,SIMCUR)*QXX(CP,SIMCUR)));
 PQTAB2(RC,SIMCUR)$SUM(C$MCRC(C,RC), QQ0(C)) = SUM(C$MCRC(C,RC), PQX(C,SIMCUR) * PQX(C,SIMCUR)*QQX(C,SIMCUR) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PQX(CP,SIMCUR)*QQX(CP,SIMCUR)));
 PETAB2(RC,SIMCUR)$SUM(C$MCRC(C,RC), QE0(C)) = SUM(C$MCRC(C,RC), PEX(C,SIMCUR) * PEX(C,SIMCUR)*QEX(C,SIMCUR) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PEX(CP,SIMCUR)*QEX(CP,SIMCUR)));
 PMTAB2(RC,SIMCUR)$SUM(C$MCRC(C,RC), QM0(C)) = SUM(C$MCRC(C,RC), PMX(C,SIMCUR) * PMX(C,SIMCUR)*QMX(C,SIMCUR) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PMX(CP,SIMCUR)*QMX(CP,SIMCUR)));

 PXTAB2(RC,SIMCUR)$PXTAB2(RC,'BASE') = (PXTAB2(RC,SIMCUR)/PXTAB2(RC,'BASE')-1)*100;
 PQTAB2(RC,SIMCUR)$PQTAB2(RC,'BASE') = (PQTAB2(RC,SIMCUR)/PQTAB2(RC,'BASE')-1)*100;
 PETAB2(RC,SIMCUR)$PETAB2(RC,'BASE') = (PETAB2(RC,SIMCUR)/PETAB2(RC,'BASE')-1)*100;
 PMTAB2(RC,SIMCUR)$PMTAB2(RC,'BASE') = (PMTAB2(RC,SIMCUR)/PMTAB2(RC,'BASE')-1)*100;

 PXTAB2(RC,'BASE')$SUM(C$MCRC(C,RC), QX0(C)) = SUM(C$MCRC(C,RC), PX0(C) * PX0(C)*QX0(C) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PX0(CP)*QX0(CP)));
 PQTAB2(RC,'BASE')$SUM(C$MCRC(C,RC), QQ0(C)) = SUM(C$MCRC(C,RC), PQ0(C) * PQ0(C)*QQ0(C) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PQ0(CP)*QQ0(CP)));
 PETAB2(RC,'BASE')$SUM(C$MCRC(C,RC), QE0(C)) = SUM(C$MCRC(C,RC), PE0(C) * PE0(C)*QE0(C) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PE0(CP)*QE0(CP)));
 PMTAB2(RC,'BASE')$SUM(C$MCRC(C,RC), QM0(C)) = SUM(C$MCRC(C,RC), PM0(C) * PM0(C)*QM0(C) / SUM(CP$(MCRC(C,RC) AND MCRC(CP,RC)), PM0(CP)*QM0(CP)));

*----------------------------------------------------------------------------------------------------------------------
*Household income and expenditure tables --------------------------------------
*----------------------------------------------------------------------------------------------------------------------

* QHTAB2(RA,SIMCUR)$SUM((H,C)$MCRA(C,RA), PQ0(C)*QH0(C,H)) = (SUM((H,C)$MCRA(C,RA), PQ0(C)*QHX(C,H,SIMCUR))/SUM((H,C)$MCRA(C,RA), PQ0(C)*QH0(C,H))-1)*100;
* QHTAB2(RA,'BASE')$SUM((H,C), PQ0(C)*QH0(C,H)) = SUM((H,C)$MCRA(C,RA), PQ0(C)*QH0(C,H))/SUM((H,C), PQ0(C)*QH0(C,H))*100;
 QHTAB2(RC,SIMCUR)$SUM((H,C)$MCRC(C,RC), PQ0(C)*QH0(C,H)) = (SUM((H,C)$MCRC(C,RC), PQ0(C)*QHX(C,H,SIMCUR))/SUM((H,C)$MCRC(C,RC), PQ0(C)*QH0(C,H))-1)*100;
 QHTAB2(RC,'BASE')$SUM((H,C), PQ0(C)*QH0(C,H)) = SUM((H,C)$MCRC(C,RC), PQ0(C)*QH0(C,H))/SUM((H,C), PQ0(C)*QH0(C,H))*100;

 YITAB(INSDNG,SIMCUR)$YIX(INSDNG,'BASE') = (YIX(INSDNG,SIMCUR)/YIX(INSDNG,'BASE')-1)*100;
 YITAB(INSDNG,'BASE') = YI0(INSDNG);
$ontext
*Ensure small shares for nontraded commodities (reporting only)
 QETAB(RA,SIMCUR)$(ABS(QETAB(RA,SIM)) LT 1E-6)                             = 0.00000001;
 QMTAB(RA,SIM)$(ABS(QMTAB(RA,SIM)) LT 1E-6)                                = 0.00000001;
 PXTAB(RA,SIM)$(ABS(PXTAB(RA,SIM)) LT 1E-6)                                = 0.00000001;
 PQTAB(RA,SIM)$(ABS(PQTAB(RA,SIM)) LT 1E-6)                                = 0.00000001;
 PETAB(RA,SIM)$(ABS(PETAB(RA,SIM)) LT 1E-6)                                = 0.00000001;
 PMTAB(RA,SIM)$(ABS(PMTAB(RA,SIM)) LT 1E-6)                                = 0.00000001;
 SGROWTH(RA,SIM)$(ABS(SGROWTH(RA,SIM)) LT 1E-6)                            = 0.00000001;
 SCONTR(RA,SIM)$(ABS(SCONTR(RA,SIM)) LT 1E-6)                              = 0.00000001;
 EVTAB(H,SIMCUR)$(ABS(EVTAB(H,SIMCUR)) LT 1E-6)                            = 0.00000001;
 EVTAB('TOTAL',SIMCUR)$(ABS(EVTAB('TOTAL',SIMCUR)) LT 1E-6)                = 0.00000001;
* QHTAB2(RA,SIM)$(ABS(QHTAB2(RA,SIM)) LT 1E-6)                             = 0.00000001;
 QHTAB2(RC,SIMCUR)$(ABS(QHTAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;
 YITAB(INSDNG,SIMCUR)$(ABS(YITAB(INSDNG,SIMCUR)) LT 1E-6)                  = 0.00000001;
*R changed from SIM to CIMCUR  
 WFXP(F,SIMCUR)$(ABS(WFXP(F,SIMCUR)) LT 1E-6)                              = 0.00000001;
 QFSXP(F,SIMCUR)$(ABS(QFSXP(F,SIMCUR)) LT 1E-6)                            = 0.00000001;
 QFXP(F,A,SIMCUR)$(ABS(QFXP(F,A,SIMCUR)) LT 1E-6)                          = 0.00000001;
 WFDISTXP(F,A,SIMCUR)$(ABS(WFDISTXP(F,A,SIMCUR)) LT 1E-6)                  = 0.00000001;
 YFXP(F,SIMCUR)$(ABS(YFXP(F,SIMCUR)) LT 1E-6)                              = 0.00000001;
 MACROTAB(SIND,SIMCUR)$(ABS(MACROTAB(SIND,SIMCUR)) LT 1E-6)                = 0.00000001;
 GDPTAB1P(KGDP,IGDP,SIMCUR)$(ABS(GDPTAB1P(KGDP,IGDP,SIMCUR)) LT 1E-6)      = 0.00000001;


*R
 QETAB2(RC,SIMCUR)$(ABS(QETAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;
 QMTAB2(RC,SIMCUR)$(ABS(QMTAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;
*DvS Mar2012
 QDTAB2(RC,SIMCUR)$(ABS(QDTAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;
 QQTAB2(RC,SIMCUR)$(ABS(QQTAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;

 PXTAB2(RC,SIMCUR)$(ABS(PXTAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;
 PQTAB2(RC,SIMCUR)$(ABS(PQTAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;
 PETAB2(RC,SIMCUR)$(ABS(PETAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;
 PMTAB2(RC,SIMCUR)$(ABS(PMTAB2(RC,SIMCUR)) LT 1E-6)                        = 0.00000001;

$offtext

$ONTEXT
*Prepare and display reporting tables -----------------------------------------
*------------------------------------------------------------------------------

OPTION
 QETAB:2:1:1,   QMTAB:2:1:1
 sVALUE:1:1:1,  sSHARE:3:1:1,  sGROWTH:2:1:1,  sCONTR:3:1:1
 dVALUE:3:1:1,  dSHARE:2:1:1,  dGROWTH:2:1:1,  dCONTR:2:1:1
 PXTAB:3:1:1,   PETAB:3:1:1,   PMTAB:3:1:1,    PQTAB:3:1:1
;

*execute_unload "0output.gdx" GDPTAB1P SGROWTH QETAB QMTAB EVTAB QHTAB2 SCONTR PXTAB PQTAB PETAB PMTAB YITAB YFXP WFXP QFSXP QFXP WFDISTXP MACROTAB
*execute 'gdxxrw.exe i=0output.gdx o=0output.xlsx index=index!g6'

PARAMETER XLTEST;
execute_unload "0output.gdx" GDPTAB1P SGROWTH QETAB QMTAB EVTAB QHTAB2 SCONTR PXTAB PQTAB PETAB PMTAB YITAB YFXP WFXP QFSXP QFXP WFDISTXP MACROTAB
execute 'xlstalk.exe -m 0output.xlsx';
 XLTEST = ERRORLEVEL;
IF(XLTEST = 1,
execute 'xlstalk.exe -c 0output.xlsx';
);
IF(XLTEST = 2,
execute 'xlstalk.exe -s 0output.xlsx';
);
execute 'gdxxrw.exe i=0output.gdx o=0output.xlsx index=index!g6'
execute 'xlstalk.exe -o 0output.xlsx';
DISPLAY XLTEST;

*execute 'xlstalk.exe -s 0output.xlsx';

$offtext

*Prepare and display reporting tables -----------------------------------------
*------------------------------------------------------------------------------
*$ontext
* factor output ratios
Parameter
  FACTAB5(A,F) output-factor ratios for activity a
  FACTAB4A(A,F) scaled up FACTAB4
   ;
*RJD These are scaled to get them into units users might comprehend
  FACTAB5(A,F)$QFX(F,A,'base') =  QAX(A,'base') / QFX(F,A,'base')/SCALE     ;
  FACTAB4A(A,F) = FACTAB4(A,F)/scale ;
*RJD Oct 2012 - printing out govt budget details
PARAMETER
YG1X(SIM)     direct tax revenues
YG2X(SIM)     factor tax revenues
YG3X(SIM)     value added tax revenues
YG4X(SIM)     activity tax revenues
YG5X(SIM)     import duty revenues
YG6X(SIM)     export tax revenues
YG7X(SIM)     sales tax revenues
YG8X(SIM)     transfers received from factors
YG9X(SIM)     transfers received from ROW
;

YG1X(SIM)  = SUM(INSDNG, TINSX(INSDNG,SIM)*YIX(INSDNG,SIM)) ;
YG2X(SIM)  = SUM(F, tfx(F,SIM)*YFX(F,SIM));
YG3X(SIM)  = SUM(A, tvax(A,SIM)*PVAX(A,SIM)*QVAX(A,SIM)) ;
YG4X(SIM)  = SUM(A, tax(A,SIM)*PAX(A,SIM)*QAX(A,SIM));
YG5X(SIM)  = SUM(C, tmx(C,SIM)*pwmx(C,SIM)*QMX(C,SIM))*EXRX(SIM) ;
YG6X(SIM)  = SUM(C, tex(C,SIM)*pwex(C,SIM)*QEX(C,SIM))*EXRX(SIM) ;
YG7X(SIM)  = SUM(C, tqx(C,SIM)*PQX(C,SIM)*QQX(C,SIM)) ;
YG8X(SIM)  = SUM(F, YIFX('GOV',F,SIM)) ;
YG9X(SIM)  = trnsfrx('GOV','ROW',SIM)*EXRX(SIM);
*RJD Oct 2012 end

*$offtext


*$ontext
OPTION
 QETAB:2:1:1,   QMTAB:2:1:1
 sVALUE:1:1:1,  sSHARE:3:1:1,  sGROWTH:2:1:1,  sCONTR:3:1:1
 dVALUE:3:1:1,  dSHARE:2:1:1,  dGROWTH:2:1:1,  dCONTR:2:1:1
 PXTAB:3:1:1,   PETAB:3:1:1,   PMTAB:3:1:1,    PQTAB:3:1:1
;

*setting a time stamp for output file
scalar dummy1 ; dummy1 = jstart+1;


PARAMETER XLTEST;

execute_unload "z0output.gdx" GDPTAB1P, MACROTAB, SGROWTH, QETAB2, QMTAB2, QDTAB2, QQTAB2, EVTAB, QHTAB2, SCONTR, PXTAB2, PQTAB2
                             PETAB2, PMTAB2, YITAB, YFXP, WFXP, QFSXP, QFXP, WFDISTXP, dummy1, STRUCBASE, FACTAB1
                             FACTAB2, FACTAB3, FACTAB4A, FACTAB5, tinsx, tqx, trnsfrx, tmx
                             YG1X,YG2X,YG3X,YG4X,YG5X,YG6X,YG7X,YG8X, YG9X, CPIX, WALRASX
                             ;


execute 'xlstalk.exe -m %reportdata%';
 XLTEST = ERRORLEVEL;
IF(XLTEST = 1,
execute 'xlstalk.exe -c %reportdata%';
);
IF(XLTEST = 2,
execute 'xlstalk.exe -s %reportdata%';
);
execute 'gdxxrw.exe i=z0output.gdx o=%reportdata% index=index!g6 merge trace=1 RWAIT=1000' ;
execute 'xlstalk.exe -o %simdata%';
execute 'xlstalk.exe -o %reportdata%';
DISPLAY XLTEST;

*$offtext
